@@ -7,7 +7,7 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Value::LayeredInclude 2.155;
+package Config::Model::Value::LayeredInclude 2.156;
 
 use v5.20;
 use Mouse;
@@ -86,7 +86,7 @@ Config::Model::Value::LayeredInclude - Include a sub layer configuration
 
 =head1 VERSION
 
-version 2.155
+version 2.156
 
 =head1 SYNOPSIS
 
@@ -108,9 +108,9 @@ version 2.155
 
 This class inherits from L<Config::Model::Value>. It overrides
 L<_store> to trigger a refresh of layered value when a value is
-changed. I.e. changing this value trigger a reload of the referred configuration
-file which values are used as default value. This class was designed to
-cope with L<multistrap|http://wiki.debian.org/Multistrap> configuration.
+changed. I.e. changing this value trigger a reload of the referred
+configuration file which values are used as default value. This class
+was designed to cope with late multistrap configuration.
 
 =head2 CAUTION
 
@@ -120,8 +120,8 @@ A configuration file can support 2 kinds of include:
 
 =item *
 
-Layered include which sets default values like multistrap or ssh. These includes are
-read-only.
+Layered include which sets default values like default values for ssh
+configuration. These includes are read-only.
 
 =item *
 
